<?php 
/**
 *Endanger functions and definitions
 *
 * @package Endanger
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'endanger_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.  
 */
function endanger_setup() { 
	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'endanger', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support('woocommerce');
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header' );
	add_filter('widget_text', 'do_shortcode');
	add_theme_support( 'title-tag' );
	add_image_size('endanger-homepage-thumb',240,145,true);
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 250,
		'flex-height' => true,
	) );
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'endanger' ),
		'footer' => __( 'Footer Menu', 'endanger' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' );
} 
endif; // endanger_setup
add_action( 'after_setup_theme', 'endanger_setup' );

function endanger_widgets_init() { 	
	
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'endanger' ),
		'description'   => __( 'Appears on blog page sidebar', 'endanger' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );	
	
}
add_action( 'widgets_init', 'endanger_widgets_init' );


function endanger_font_url(){
		$font_url = '';		
		
		/* Translators: If there are any character that are not
		* supported by Montserrat, trsnalate this to off, do not
		* translate into your own language.
		*/
		$montserrat = _x('on','montserrat:on or off','endanger');		
		
		
		/* Translators: If there has any character that are not supported 
		*  by Scada, translate this to off, do not translate
		*  into your own language.
		*/
		$scada = _x('on','Scada:on or off','endanger');	
		
		if('off' !== $montserrat ){
			$font_family = array();
			
			if('off' !== $montserrat){
				$font_family[] = 'Montserrat:300,400,600,700,800,900';
			}
					
						
			$query_args = array(
				'family'	=> urlencode(implode('|',$font_family)),
			);
			
			$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
		}
		
	return $font_url;
	}


function endanger_scripts() {
	wp_enqueue_style('endanger-font', endanger_font_url(), array());
	wp_enqueue_style( 'endanger-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'endanger-editor-style', get_template_directory_uri()."/editor-style.css" );
	wp_enqueue_style( 'nivo-style', get_template_directory_uri()."/css/nivo-slider.css" );
	wp_enqueue_style( 'endanger-responsive-style', get_template_directory_uri()."/css/responsive.css" );		
	wp_enqueue_style( 'endanger-default-style', get_template_directory_uri()."/css/default.css" );
	wp_enqueue_script( 'nivo-jquery', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'endanger-custom-jquery', get_template_directory_uri() . '/js/custom.js' );
	wp_enqueue_style( 'animation-style', get_template_directory_uri()."/css/animation.css" );	
	wp_enqueue_style( 'font-awesome-style', get_template_directory_uri()."/css/font-awesome.css" );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'endanger_scripts' );

function endanger_ie_stylesheet(){
	global $wp_styles;
	
	/** Load our IE-only stylesheet for all versions of IE.
	*   <!--[if lt IE 9]> ... <![endif]-->
	*
	*  Note: It is also possible to just check and see if the $is_IE global in WordPress is set to true before
	*  calling the wp_enqueue_style() function. If you are trying to load a stylesheet for all browsers
	*  EXCEPT for IE, then you would HAVE to check the $is_IE global since WordPress doesn't have a way to
	*  properly handle non-IE conditional comments.
	*/
	wp_enqueue_style('endanger-ie', get_template_directory_uri().'/css/ie.css', array('endanger-style'));
	$wp_styles->add_data('endanger-ie','conditional','IE');
	}
add_action('wp_enqueue_scripts','endanger_ie_stylesheet');

define('Grace_URL','https://www.gracethemes.com','endanger');
define('Grace_THEME_DOC','https://gracethemes.com/documentation/endanger-doc/','endanger');
define('Grace_PRO_THEME_URL','https://gracethemes.com/themes/adventure-wordpress-theme/','endanger');
define('Grace_LIVE_DEMO','https://gracethemes.com/demo/endanger/','endanger');


function endanger_themebytext(){
		return "Design & Develop by <a href=".esc_url(Grace_URL)." target='_blank'>Grace Themes</a>";
}
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom template for about theme.
 */
require get_template_directory() . '/inc/about-themes.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

if ( ! function_exists( 'endanger_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 */
function endanger_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;


// get slug by id
function endanger_get_slug_by_id($id) {
	$post_data = get_post($id, ARRAY_A);
	$slug = $post_data['post_name'];
	return $slug; 
}